!-------------------
!  definition du champ de vitesse (vx,vy)
!-------------------

module mod_vitesse

  use mod_precision

contains

function vx(x,y)
  
  implicit none
    
  real(pr), intent(in) :: x,y
  real(pr) :: vx
  real(pr) :: r,pi

  !--- definition de vx
  
  !- exemple 1 : rotation rigide
  vx=-y

!!$  !- exemple 2 : couette cylindrique
!!$  r=sqrt(x**2+y**2)
!!$  pi=acos(-1.0_pr)
!!$  vx=-y/r*4*pi/3._pr*(r-1._pr/r)
!!$
!!$  !- exemples 3 et 4 : vitesse a potentiel complexe
!!$  pi=acos(-1.0_pr)
!!$  vx=-1._pr/(2._pr*pi)*(x**2+y**2)**(-2)*2._pr*x**2+1._pr+1._pr/(2._pr*pi*(x**2+y**2))

end function vx


function vy(x,y)
  
  implicit none
    
  real(pr), intent(in) :: x,y
  real(pr) :: vy
  real(pr) :: r,pi

  !--- definition de vy

  !- exemple 1 : rotation rigide
  vy=x-0.5_pr

!!$  !- exemple 2 : couette cylindrique
!!$  r=sqrt(x**2+y**2)
!!$  pi=acos(-1.0_pr)
!!$  vy=x/r*4*pi/3._pr*(r-1._pr/r)
!!$
!!$  !- exemples 3, 4, et 5 : vitesse a potentiel complexe
!!$  pi=acos(-1.0_pr)
!!$  vy=-1._pr/(2._pr*pi)*(x**2+y**2)**(-2)*2._pr*x*y


end function vy


end module mod_vitesse
